@@ -4,9 +4,11 @@ declare(strict_types=1);
 
 namespace Doctrine\DBAL\Tests\Functional\Driver;
 
+use Doctrine\DBAL\Schema\Column;
 use Doctrine\DBAL\Schema\Table;
 use Doctrine\DBAL\Tests\FunctionalTestCase;
 use Doctrine\DBAL\Tests\TestUtil;
+use Doctrine\DBAL\Types\Types;
 
 class DBAL6044Test extends FunctionalTestCase
 {
@@ -23,13 +25,29 @@ class DBAL6044Test extends FunctionalTestCase
 
     public function testUnloggedTables(): void
     {
-        $unloggedTable = new Table('my_unlogged');
-        $unloggedTable->addOption('unlogged', true);
-        $unloggedTable->addColumn('foo', 'string');
+        $unloggedTable = Table::editor()
+            ->setUnquotedName('my_unlogged')
+            ->setColumns(
+                Column::editor()
+                    ->setUnquotedName('foo')
+                    ->setTypeName(Types::STRING)
+                    ->create(),
+            )
+            ->setOptions(['unlogged' => true])
+            ->create();
+
         $this->dropAndCreateTable($unloggedTable);
 
-        $loggedTable = new Table('my_logged');
-        $loggedTable->addColumn('foo', 'string');
+        $loggedTable = Table::editor()
+            ->setUnquotedName('my_logged')
+            ->setColumns(
+                Column::editor()
+                    ->setUnquotedName('foo')
+                    ->setTypeName(Types::STRING)
+                    ->create(),
+            )
+            ->create();
+
         $this->dropAndCreateTable($loggedTable);
 
         $schemaManager = $this->connection->createSchemaManager();
